/*====================PROCEDIMENTO CANCELA_DADOS_FINANCEIRO=====================

   VERIFICA SE AS INFORMAES FINANCEIRAS DA NOTA FISCAL PODEM SER APAGADAS
   DO SISTEMA. EM CASO AFIRMATIVO, A ROTINA APAGA AS INFORMAES FINANCEIRAS
   REFERENTES  NOTA FISCAL APROVADA (AJUSTES E BOLETO). EM CASO CONTRRIO,
   RETORNA UM VALOR CORRESPONDENTE AO MOTIVO DE BLOQUEIO DO CANCELAMENTO.

   -------
   ENTRADA
   -------
      O PROCEDIMENTO POSSUI OS SEGUINTES PARMETROS DE ENTRADA :

      - P_CDFILIAL    : CDIGO DA FILIAL DE LANAMENTO DA NOTA FISCAL
      - P_NRLANCTONF  : NMERO DE LANAMENTO DA NOTA FISCAL

   -----
   SADA
   -----
      O RETORNO DO PROCEDIMENTO SE D ATRAVS DO SEGUINTE PARMETRO :
      - P_RETORNO     : '0' - CANCELAMENTO FINANCEIRO CONCLUDO
                      : '1' - NOTA POSSUI CONTA BAIXADA
                      : '2' - NOTA POSSUI CONTA PARCELADA
                      : '4' - NOTA POSSUI AJUSTES EM BOLETO DAS CONTAS
                      : '5' - NOTA POSSUI CONTA COM BOLETO REAL (PARA CONTAS A PAGAR)
                              NOTA POSSUI CONTA COM BOLETO EMITIDO (PARA CONTAS A RECEBER)
                      : '6' - NOTA POSSUI CONTA ENVIADA AO BANCO VIA CNAB
                      : '7' - NOTA POSSUI CONTA DE UM BOLETO ASSOCIADO
                      : '8' - NOTA DE DEVOLUO POSSUI VALOR UTILIZADO
                      : '9' - NOTA POSSUI CONTA BAIXADA PARA O IMPOSTO RETIDO
                      : '10' - NOTA POSSUI CONTA PARCELADA PARA O IMPOSTO RETIDO
                      : '11' - NOTA POSSUI AJUSTES EM BOLETO DAS CONTAS DO IMPOSTO RETIDO
                      : '12' - NOTA POSSUI CONTA COM BOLETO REAL (PARA CONTAS A PAGAR) DO IMPOSTO RETIDO
                      : '13' - NOTA POSSUI CONTA ENVIADA AO BANCO VIA CNAB DO IMPOSTO RETIDO
                      : '14' - NOTA POSSUI CONTA DE UM BOLETO ASSOCIADO IMPOSTO RETIDO
                      : '15' - NOTA DE DEVOLUO POSSUI VALOR UTILIZADO IMPOSTO RETIDO

 DEBUGAR PROCEDURE
 raise_application_error(-20501, '' , True);
*/

CREATE OR REPLACE PROCEDURE CANCELA_DADOS_FINANCEIRO(P_CDFILIAL IN NOTAFISCAL.CDFILIAL%TYPE,
                                                     P_NRLANCTONF IN NOTAFISCAL.NRLANCTONF%TYPE,
                                                     P_IDCANFIN IN VARCHAR2 DEFAULT 'S',
                                                     P_RETORNO OUT NUMBER)
AS
   V_COUNT NUMBER;
   V_RESULTADO NUMBER;
   V_FATOR NUMBER;
   V_IDENTRSAID VARCHAR2(1);
BEGIN
   /*BUSCA AS INFORMAES DA NOTA FISCAL*/
   SELECT IDENTRSAIDOP
     INTO V_IDENTRSAID
     FROM NOTAFISCAL
    WHERE CDFILIAL = P_CDFILIAL
      AND NRLANCTONF = P_NRLANCTONF;
   /*NOTA FISCAL DE ENTRADA*/
   IF V_IDENTRSAID = 'E' THEN
       /*VERIFICA SE EXISTE GUIAPAGDOC OU ITEMNOTAGPS REFERENTE A GUIA DO IMPOSTO*/
       FOR C_NFDARF IN (SELECT GP.CDFILIAL, GP.NRLANCTONFDARF, CP.CDFILIBPAG, CP.NRLANBOLPAG
                          FROM CONTAPAGAR CP, GUIAPAGDOC GP
                         WHERE GP.CDFILIAL       = CP.CDFILIAL
                           AND GP.NRLANCTONFDARF = CP.NRLANCTONF
                           AND GP.CDFILIAL       = P_CDFILIAL
                           AND GP.NRLANCTONF     = P_NRLANCTONF
                         UNION ALL
                        SELECT IT.CDFILIALGPS, IT.NRLANCTONFGPS, CP.CDFILIBPAG, CP.NRLANBOLPAG
                          FROM CONTAPAGAR CP, ITEMNOTAGPS IT
                         WHERE IT.CDFILIALGPS    = CP.CDFILIAL
                           AND IT.NRLANCTONFGPS  = CP.NRLANCTONF
                           AND IT.CDFILIAL       = P_CDFILIAL
                           AND IT.NRLANCTONF     = P_NRLANCTONF)LOOP

          /*VERIFICA EXISTNCIA DE CONTA A PAGAR BAIXADA*/
         SELECT COUNT(BO.CDFILIAL)
           INTO V_COUNT
           FROM CONTAPAGAR CP,
                BOLETPAGAR BO
          WHERE (BO.CDFILIAL    = C_NFDARF.CDFILIAL)
            AND (BO.NRLANBOLPAG = C_NFDARF.NRLANCTONFDARF)
            AND (BO.CDFILIAL    = CP.CDFILIBPAG)
            AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
            AND (BO.NRBAIXAPAG IS NOT NULL);
          IF V_COUNT > 0 THEN
            P_RETORNO := 9;
          ELSE
             /*VERIFICA EXISTNCIA DE CONTAS PARCELADAS REFERENTE A GUIA DO IMPOSTO*/
            SELECT COUNT(*)
              INTO V_COUNT
              FROM CONTAPAGAR CP
             WHERE (CP.CDFILIAL = C_NFDARF.CDFILIAL)
               AND (CP.NRLANCTONF = C_NFDARF.NRLANCTONFDARF)
               AND (SELECT COUNT(*)
                      FROM CONTAPAGAR
                     WHERE CDFILIAL = C_NFDARF.CDFILIAL
                       AND NRLANCTONF = C_NFDARF.NRLANCTONFDARF
                       AND NRSEQVENPAG = CP.NRSEQVENPAG) > 1;
            IF V_COUNT > 0 THEN
               P_RETORNO := 10;
            ELSE
               /*VERIFICA EXISTNCIA DE BOLETO REAL REFERENTE A GUIA DO IMPOSTO*/
               SELECT COUNT(BO.CDFILIAL)
                 INTO V_COUNT
                 FROM CONTAPAGAR CP,
                      BOLETPAGAR BO
                WHERE (CP.CDFILIAL = C_NFDARF.CDFILIAL)
                  AND (CP.NRLANCTONF = C_NFDARF.NRLANCTONFDARF)
                  AND (BO.CDFILIAL = CP.CDFILIBPAG)
                  AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
                  AND (BO.IDBPAGREAL = 'S');
               IF V_COUNT > 0 THEN
                  P_RETORNO := 12;
               ELSE
                  /*VERIFICA EXISTNCIA DE BOLETO LIGADO  REMESSA REFERENTE A GUIA DO IMPOSTO*/
                  SELECT COUNT(BO.CDFILIAL)
                    INTO V_COUNT
                    FROM CONTAPAGAR CP,
                         BOLETPAGAR BO
                   WHERE (CP.CDFILIAL = C_NFDARF.CDFILIAL)
                     AND (CP.NRLANCTONF = C_NFDARF.NRLANCTONFDARF)
                     AND (BO.CDFILIAL = CP.CDFILIBPAG)
                     AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
                     AND (IDSITUCNABP <> '00');
                  IF V_COUNT > 0 THEN
                     P_RETORNO := 13;
                  ELSE
                     /*VERIFICA EXISTNCIA DE BOLETO ASSOCIADO  NOTA FISCAL DIFERENTE REFERENTE A GUIA DO IMPOSTO*/
                     SELECT COUNT(*)
                       INTO V_COUNT
                       FROM (SELECT DISTINCT C.CDFILIAL, C.NRLANCTONF
                               FROM CONTAPAGAR C,
                                    (SELECT DISTINCT CDFILIBPAG as CDFILIAL, NRLANBOLPAG
                                       FROM CONTAPAGAR CP
                                      WHERE (CP.CDFILIAL   = C_NFDARF.CDFILIAL)
                                        AND (CP.NRLANCTONF = C_NFDARF.NRLANCTONFDARF)) BO
                      WHERE BO.CDFILIAL    = C.CDFILIBPAG
                        AND BO.NRLANBOLPAG = C.NRLANBOLPAG) A;

                     IF V_COUNT > 1 THEN
                          P_RETORNO := 14;
                     ELSE
                        /*VERIFICA SE A NOTA FISCAL DE DEVOLUO TEM VALOR UTILIZADO REFERENTE A GUIA DO IMPOSTO*/
                        SELECT NVL(VRDEVOLNFUTL,0) VRDEVOLNFUTL
                          INTO V_COUNT
                          FROM NOTAFISCAL
                         WHERE CDFILIAL   = C_NFDARF.CDFILIAL
                           AND NRLANCTONF = C_NFDARF.NRLANCTONFDARF;
                        IF V_COUNT > 0 THEN
                           P_RETORNO := 15;
                        ELSE
                           /*VERIFICA SE A NOTA POSSUI VENCIMENTOS LIGADOS  ANTECIPAO DE FORNECEDORES REFERENTE A GUIA DO IMPOSTO
                           (MENSAGEM DE DOCUMENTO POSSUI BOLETO REAL)*/
                           SELECT COUNT(B.CDFILIAL)
                             INTO V_COUNT
                             FROM CONTAPAGAR C, BOLETPAGAR B
                            WHERE C.CDFILIAL = C_NFDARF.CDFILIAL
                              AND C.NRLANCTONF = C_NFDARF.NRLANCTONFDARF
                              AND C.CDFILIBPAG = B.CDFILIAL
                              AND C.NRLANBOLPAG = B.NRLANBOLPAG
                              AND B.NRLANCANTECIPA IS NOT NULL;
                           IF V_COUNT > 0 THEN
                              P_RETORNO := 12;
                           ELSE
                              /*PESQUISA A EXISTNCIA DE AJUSTES NOS BOLETOS DAS CONTAS REFERENTE A GUIA DO IMPOSTO*/
                              /*essa precisa ser a ultima validao da procedure  */
                              SELECT COUNT(AJ.CDFILIAL)
                                INTO V_COUNT
                                FROM CONTAPAGAR CP,
                                     AJBOLPAG   AJ
                               WHERE (CP.CDFILIAL = C_NFDARF.CDFILIAL)
                                 AND (CP.NRLANCTONF = C_NFDARF.NRLANCTONFDARF)
                                 AND (AJ.CDFILIAL = CP.CDFILIBPAG)
                                 AND (AJ.NRLANBOLPAG = CP.NRLANBOLPAG);
                              IF V_COUNT > 0 THEN
                                 P_RETORNO := 11;
                              ELSE
                                 P_RETORNO := 0;
                                 IF (NVL(P_IDCANFIN, 'S') = 'S') THEN
                                   /*APAGA AS CONTAS A PAGAR REFERENTES A GUIA*/
                                   FOR C_CNTPAGAR IN (SELECT CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                                                             DTATUAVENPAG, VRORIGPAG, IDMOVFLUXO, DTMOVFLUXO,
                                                             CDCLASSFINA, CDFILIBPAG, NRLANBOLPAG, CDEMPRESA, CDFIMOVFLPAG
                                                        FROM CONTAPAGAR
                                                       WHERE CDFILIAL = C_NFDARF.CDFILIAL
                                                         AND NRLANCTONF = C_NFDARF.NRLANCTONFDARF) LOOP
                                      /*ATUALIZA ORAMENTO FINANCEIRO REFERENTES A GUIA*/
                                      ORCAMENTO_OK(C_CNTPAGAR.CDEMPRESA,
                                                   C_CNTPAGAR.CDFIMOVFLPAG,
                                                   C_CNTPAGAR.CDCLASSFINA,
                                                   C_CNTPAGAR.DTATUAVENPAG,
                                                   C_CNTPAGAR.VRORIGPAG * -1,
                                                   V_RESULTADO);
                                      /*APAGA O RATEIO DA CONTA A PAGAR REFERENTES A GUIA*/
                                      DELETE FROM RATCTPAGAR
                                       WHERE CDFILIAL     = C_CNTPAGAR.CDFILIAL
                                         AND NRLANCTONF   = C_CNTPAGAR.NRLANCTONF
                                         AND NRSEQVENPAG  = C_CNTPAGAR.NRSEQVENPAG
                                         AND NRPARCELAPAG = C_CNTPAGAR.NRPARCELAPAG;
                                      /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                      FOR C_AJPAGAR IN (SELECT AJ.CDFILIAL, AJ.NRLANCTONF, AJ.NRSEQVENPAG, AJ.NRPARCELAPAG,
                                                               AJ.DTAJUSTEPAG, AJ.CDAJUCTPAG, T.IDAJUCTPAG, AJ.CDEMMFAJCNTP,
                                                               AJ.CDFIMFAJCNTP, AJ.CDCLASSFINA, AJ.IDMOVFLUXO, AJ.VRAJUSTEPAG,
                                                               AJ.DTMOVFLUXO
                                                          FROM AJCTPAGAR AJ, TIPOAJPAGAR T
                                                         WHERE AJ.CDFILIAL = C_CNTPAGAR.CDFILIAL
                                                           AND AJ.NRLANCTONF = C_CNTPAGAR.NRLANCTONF
                                                           AND AJ.NRSEQVENPAG = C_CNTPAGAR.NRSEQVENPAG
                                                           AND AJ.NRPARCELAPAG = C_CNTPAGAR.NRPARCELAPAG
                                                           AND AJ.CDAJUCTPAG = T.CDAJUCTPAG) LOOP
                                         IF C_AJPAGAR.IDAJUCTPAG = 'D' THEN
                                            V_FATOR := 1;
                                         ELSE
                                            V_FATOR := -1;
                                         END IF;
                                         IF NOT (C_AJPAGAR.CDEMMFAJCNTP IS NULL)
                                            AND NOT (C_AJPAGAR.CDFIMFAJCNTP IS NULL)
                                            AND NOT (C_AJPAGAR.DTMOVFLUXO IS NULL)
                                            AND NOT (C_AJPAGAR.CDCLASSFINA IS NULL) THEN
                                            /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE REFERENTES A GUIA*/
                                            ATUALIZA_FLUXO_DE_CAIXA(C_AJPAGAR.CDEMMFAJCNTP,
                                                                    C_AJPAGAR.CDFIMFAJCNTP,
                                                                    C_AJPAGAR.DTMOVFLUXO,
                                                                    C_AJPAGAR.IDMOVFLUXO,
                                                                    C_AJPAGAR.CDCLASSFINA,
                                                                    0,
                                                                    C_AJPAGAR.VRAJUSTEPAG * V_FATOR);
                                         END IF;
                                         /*APAGA OS AJUSTES DA CONTA A PAGAR REFERENTES A GUIA*/
                                         DELETE FROM AJCTPAGAR
                                          WHERE (CDFILIAL     = C_AJPAGAR.CDFILIAL)
                                            AND (NRLANCTONF   = C_AJPAGAR.NRLANCTONF)
                                            AND (NRSEQVENPAG  = C_AJPAGAR.NRSEQVENPAG)
                                            AND (NRPARCELAPAG = C_AJPAGAR.NRPARCELAPAG)
                                            AND (DTAJUSTEPAG  = C_AJPAGAR.DTAJUSTEPAG)
                                            AND (CDAJUCTPAG   = C_AJPAGAR.CDAJUCTPAG);
                                      END LOOP;
                                      /*ATUALIZA O FLUXO DE CAIXA DA CONTA A PAGAR REFERENTES A GUIA*/
                                      /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                      IF NOT (C_CNTPAGAR.CDEMPRESA IS NULL)
                                         AND NOT (C_CNTPAGAR.CDFIMOVFLPAG IS NULL)
                                         AND NOT (C_CNTPAGAR.DTMOVFLUXO IS NULL)
                                         AND NOT (C_CNTPAGAR.CDCLASSFINA IS NULL) THEN
                                         ATUALIZA_FLUXO_DE_CAIXA(C_CNTPAGAR.CDEMPRESA,
                                                                 C_CNTPAGAR.CDFIMOVFLPAG,
                                                                 C_CNTPAGAR.DTMOVFLUXO,
                                                                 C_CNTPAGAR.IDMOVFLUXO,
                                                                 C_CNTPAGAR.CDCLASSFINA,
                                                                 0,
                                                                 C_CNTPAGAR.VRORIGPAG * -1);
                                      END IF;
                                      /*ATUALIZA AS INFORMAES DA CONTA A PAGAR REFERENTES A GUIA, RETIRANDO
                                      AS INFORMAES ATUALIZADAS NA APROVAO*/
                                      UPDATE CONTAPAGAR
                                         SET
                                            CDTPCTPAGAR = NULL,
                                            CDFILIBPAG = NULL,
                                            NRLANBOLPAG = NULL,
                                            CDCLASSFINA = NULL,
                                            CDEMPRESA = NULL,
                                            CDFIMOVFLPAG = NULL,
                                            DTMOVFLUXO = NULL,
                                            IDMOVFLUXO = NULL,
                                            DSCONTAPAG = DECODE(IDDSCONTANF,'N',NULL,DSCONTAPAG),
                                            VRATUAPAG =  VRORIGPAG
                                         WHERE CDFILIAL = C_CNTPAGAR.CDFILIAL
                                           AND NRLANCTONF = C_CNTPAGAR.NRLANCTONF
                                           AND NRSEQVENPAG = C_CNTPAGAR.NRSEQVENPAG
                                           AND NRPARCELAPAG = C_CNTPAGAR.NRPARCELAPAG;

                                      SELECT COUNT(*)
                                        INTO V_COUNT
                                        FROM CONTAPAGAR
                                       WHERE CDFILIBPAG = C_CNTPAGAR.CDFILIBPAG
                                         AND NRLANBOLPAG = C_CNTPAGAR.NRLANBOLPAG;

                                      /*APAGA O BOLETO RELACIONADO  CONTA A PAGAR REFERENTE A GUIA*/
                                      IF V_COUNT = 0 THEN
                                         DELETE FROM BOLETPAGAR
                                          WHERE CDFILIAL = C_CNTPAGAR.CDFILIBPAG
                                            AND NRLANBOLPAG = C_CNTPAGAR.NRLANBOLPAG;
                                         /*APAGA A CONTA A PAGAR REFERENTE A GUIA*/
                                         DELETE FROM CONTAPAGAR
                                          WHERE CDFILIAL = C_CNTPAGAR.CDFILIAL
                                            AND NRLANCTONF = C_CNTPAGAR.NRLANCTONF;

                                         DELETE FROM NOTAFISCAL
                                          WHERE CDFILIAL = C_CNTPAGAR.CDFILIAL
                                            AND NRLANCTONF = C_CNTPAGAR.NRLANCTONF;
                                      END IF;
                                   END LOOP;

                                   /*ATUALIZAO DAS CONTAS A PAGAR RELACIONADAS  AUTORIZAO DE FORNECIMENTO*/
                                   FOR C_NOTA IN (SELECT CDFILIALIT, NRLANCTONFIT
                                                    FROM ITEMNOTAFISC
                                                   WHERE CDFILIAL = P_CDFILIAL
                                                     AND NRLANCTONF = P_NRLANCTONF) LOOP

                                      AJUSTE_CONTAPAGAR_NF(C_NOTA.CDFILIALIT,
                                                           C_NOTA.NRLANCTONFIT,
                                                          'P');
                                   END LOOP;

                                   AJUSTE_CONTAPAGAR_NF(P_CDFILIAL,
                                                        P_NRLANCTONF,
                                                        'P');
                                 END IF;
                              END IF;
                           END IF;
                        END IF;
                     END IF;
                  END IF;
               END IF;
            END IF;
          END IF;
       END LOOP;
      IF ((P_RETORNO IS NULL) OR (P_RETORNO = 0)) THEN
         /*VERIFICA EXISTNCIA DE CONTA A PAGAR BAIXADA*/
         SELECT COUNT(BO.CDFILIAL)
           INTO V_COUNT
           FROM CONTAPAGAR CP,
                BOLETPAGAR BO
          WHERE (CP.CDFILIAL    = P_CDFILIAL)
            AND (CP.NRLANCTONF  = P_NRLANCTONF)
            AND (BO.CDFILIAL    = CP.CDFILIBPAG)
            AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
            AND (BO.NRBAIXAPAG IS NOT NULL);
         IF V_COUNT > 0 THEN
            P_RETORNO := 1;
         ELSE
            /*VERIFICA EXISTNCIA DE CONTAS PARCELADAS*/
            SELECT COUNT(*)
              INTO V_COUNT
              FROM CONTAPAGAR CP
             WHERE (CP.CDFILIAL = P_CDFILIAL)
               AND (CP.NRLANCTONF = P_NRLANCTONF)
               AND (SELECT COUNT(*)
                      FROM CONTAPAGAR
                     WHERE CDFILIAL = CP.CDFILIAL
                       AND NRLANCTONF = CP.NRLANCTONF
                       AND NRSEQVENPAG = CP.NRSEQVENPAG) > 1;
            IF V_COUNT > 0 THEN
               P_RETORNO := 2;
            ELSE

               /*VERIFICA EXISTNCIA DE BOLETO REAL*/
               SELECT COUNT(BO.CDFILIAL)
                 INTO V_COUNT
                 FROM CONTAPAGAR CP,
                      BOLETPAGAR BO
                WHERE (CP.CDFILIAL = P_CDFILIAL)
                  AND (CP.NRLANCTONF = P_NRLANCTONF)
                  AND (BO.CDFILIAL = CP.CDFILIBPAG)
                  AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
                  AND (BO.IDBPAGREAL = 'S');
               IF V_COUNT > 0 THEN
                  P_RETORNO := 5;
               ELSE
                  /*VERIFICA EXISTNCIA DE BOLETO LIGADO  REMESSA*/
                  SELECT COUNT(BO.CDFILIAL)
                    INTO V_COUNT
                    FROM CONTAPAGAR CP,
                         BOLETPAGAR BO
                   WHERE (CP.CDFILIAL = P_CDFILIAL)
                     AND (CP.NRLANCTONF = P_NRLANCTONF)
                     AND (BO.CDFILIAL = CP.CDFILIBPAG)
                     AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
                     AND (IDSITUCNABP <> '00');
                  IF V_COUNT > 0 THEN
                     P_RETORNO := 6;
                  ELSE
                     /*VERIFICA EXISTNCIA DE BOLETO ASSOCIADO  NOTA FISCAL DIFERENTE*/
                     SELECT COUNT(*)
                       INTO V_COUNT
                       FROM (SELECT DISTINCT C.CDFILIAL, C.NRLANCTONF
                               FROM CONTAPAGAR C,
                                    (SELECT DISTINCT CDFILIBPAG as CDFILIAL, NRLANBOLPAG
                                       FROM CONTAPAGAR CP
                                      WHERE (CP.CDFILIAL   = P_CDFILIAL)
                                        AND (CP.NRLANCTONF = P_NRLANCTONF)) BO
                      WHERE BO.CDFILIAL    = C.CDFILIBPAG
                        AND BO.NRLANBOLPAG = C.NRLANBOLPAG) A;

                     IF V_COUNT > 1 THEN
                          P_RETORNO := 7;
                     ELSE
                        /*VERIFICA SE A NOTA FISCAL DE DEVOLUO TEM VALOR UTILIZADO*/
                        SELECT NVL(VRDEVOLNFUTL,0) VRDEVOLNFUTL
                          INTO V_COUNT
                          FROM NOTAFISCAL
                         WHERE CDFILIAL   = P_CDFILIAL
                           AND NRLANCTONF = P_NRLANCTONF;
                        IF V_COUNT > 0 THEN
                           P_RETORNO := 8;
                        ELSE
                           /*VERIFICA SE A NOTA POSSUI VENCIMENTOS LIGADOS  ANTECIPAO DE FORNECEDORES
                           (MENSAGEM DE DOCUMENTO POSSUI BOLETO REAL)*/
                           SELECT COUNT(B.CDFILIAL)
                             INTO V_COUNT
                             FROM CONTAPAGAR C, BOLETPAGAR B
                            WHERE C.CDFILIAL = P_CDFILIAL
                              AND C.NRLANCTONF = P_NRLANCTONF
                              AND C.CDFILIBPAG = B.CDFILIAL
                              AND C.NRLANBOLPAG = B.NRLANBOLPAG
                              AND B.NRLANCANTECIPA IS NOT NULL;
                           IF V_COUNT > 0 THEN
                              P_RETORNO := 5;
                           ELSE
                              /*PESQUISA A EXISTNCIA DE AJUSTES NOS BOLETOS DAS CONTAS*/
                              /*essa precisa ser a ultima validao da procedure  */
                              SELECT COUNT(AJ.CDFILIAL)
                                INTO V_COUNT
                                FROM CONTAPAGAR CP,
                                     AJBOLPAG   AJ
                               WHERE (CP.CDFILIAL = P_CDFILIAL)
                                 AND (CP.NRLANCTONF = P_NRLANCTONF)
                                 AND (AJ.CDFILIAL = CP.CDFILIBPAG)
                                 AND (AJ.NRLANBOLPAG = CP.NRLANBOLPAG);
                              IF V_COUNT > 0 THEN
                                 P_RETORNO := 4;
                              ELSE
                                 P_RETORNO := 0;
                                 IF (NVL(P_IDCANFIN, 'S') = 'S') THEN
                                    /*APAGA AS CONTAS A PAGAR*/
                                    FOR C_CNTPAGAR IN (SELECT CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                                                              DTATUAVENPAG, VRORIGPAG, IDMOVFLUXO, DTMOVFLUXO,
                                                              CDCLASSFINA, CDFILIBPAG, NRLANBOLPAG, CDEMPRESA, CDFIMOVFLPAG
                                                         FROM CONTAPAGAR
                                                        WHERE CDFILIAL = P_CDFILIAL
                                                          AND NRLANCTONF = P_NRLANCTONF) LOOP
                                       /*ATUALIZA ORAMENTO FINANCEIRO*/
                                       ORCAMENTO_OK(C_CNTPAGAR.CDEMPRESA,
                                                    C_CNTPAGAR.CDFIMOVFLPAG,
                                                    C_CNTPAGAR.CDCLASSFINA,
                                                    C_CNTPAGAR.DTATUAVENPAG,
                                                    C_CNTPAGAR.VRORIGPAG * -1,
                                                    V_RESULTADO);
                                       /*APAGA O RATEIO DA CONTA A PAGAR*/
                                       DELETE FROM RATCTPAGAR
                                        WHERE CDFILIAL     = C_CNTPAGAR.CDFILIAL
                                          AND NRLANCTONF   = C_CNTPAGAR.NRLANCTONF
                                          AND NRSEQVENPAG  = C_CNTPAGAR.NRSEQVENPAG
                                          AND NRPARCELAPAG = C_CNTPAGAR.NRPARCELAPAG;
                                       /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                       FOR C_AJPAGAR IN (SELECT AJ.CDFILIAL, AJ.NRLANCTONF, AJ.NRSEQVENPAG, AJ.NRPARCELAPAG,
                                                                AJ.DTAJUSTEPAG, AJ.CDAJUCTPAG, T.IDAJUCTPAG, AJ.CDEMMFAJCNTP,
                                                                AJ.CDFIMFAJCNTP, AJ.CDCLASSFINA, AJ.IDMOVFLUXO, AJ.VRAJUSTEPAG,
                                                                AJ.DTMOVFLUXO
                                                           FROM AJCTPAGAR AJ, TIPOAJPAGAR T
                                                          WHERE AJ.CDFILIAL = C_CNTPAGAR.CDFILIAL
                                                            AND AJ.NRLANCTONF = C_CNTPAGAR.NRLANCTONF
                                                            AND AJ.NRSEQVENPAG = C_CNTPAGAR.NRSEQVENPAG
                                                            AND AJ.NRPARCELAPAG = C_CNTPAGAR.NRPARCELAPAG
                                                            AND AJ.CDAJUCTPAG = T.CDAJUCTPAG) LOOP
                                          IF C_AJPAGAR.IDAJUCTPAG = 'D' THEN
                                             V_FATOR := 1;
                                          ELSE
                                             V_FATOR := -1;
                                          END IF;
                                          IF NOT (C_AJPAGAR.CDEMMFAJCNTP IS NULL)
                                             AND NOT (C_AJPAGAR.CDFIMFAJCNTP IS NULL)
                                             AND NOT (C_AJPAGAR.DTMOVFLUXO IS NULL)
                                             AND NOT (C_AJPAGAR.CDCLASSFINA IS NULL) THEN
                                             /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                             ATUALIZA_FLUXO_DE_CAIXA(C_AJPAGAR.CDEMMFAJCNTP,
                                                                     C_AJPAGAR.CDFIMFAJCNTP,
                                                                     C_AJPAGAR.DTMOVFLUXO,
                                                                     C_AJPAGAR.IDMOVFLUXO,
                                                                     C_AJPAGAR.CDCLASSFINA,
                                                                     0,
                                                                     C_AJPAGAR.VRAJUSTEPAG * V_FATOR);
                                          END IF;
                                          /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                          DELETE FROM AJCTPAGAR
                                           WHERE (CDFILIAL     = C_AJPAGAR.CDFILIAL)
                                             AND (NRLANCTONF   = C_AJPAGAR.NRLANCTONF)
                                             AND (NRSEQVENPAG  = C_AJPAGAR.NRSEQVENPAG)
                                             AND (NRPARCELAPAG = C_AJPAGAR.NRPARCELAPAG)
                                             AND (DTAJUSTEPAG  = C_AJPAGAR.DTAJUSTEPAG)
                                             AND (CDAJUCTPAG   = C_AJPAGAR.CDAJUCTPAG);
                                       END LOOP;
                                       /*ATUALIZA O FLUXO DE CAIXA DA CONTA A PAGAR*/
                                       /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                       IF NOT (C_CNTPAGAR.CDEMPRESA IS NULL)
                                          AND NOT (C_CNTPAGAR.CDFIMOVFLPAG IS NULL)
                                          AND NOT (C_CNTPAGAR.DTMOVFLUXO IS NULL)
                                          AND NOT (C_CNTPAGAR.CDCLASSFINA IS NULL) THEN
                                          ATUALIZA_FLUXO_DE_CAIXA(C_CNTPAGAR.CDEMPRESA,
                                                                  C_CNTPAGAR.CDFIMOVFLPAG,
                                                                  C_CNTPAGAR.DTMOVFLUXO,
                                                                  C_CNTPAGAR.IDMOVFLUXO,
                                                                  C_CNTPAGAR.CDCLASSFINA,
                                                                  0,
                                                                  C_CNTPAGAR.VRORIGPAG * -1);
                                       END IF;
                                       /*ATUALIZA AS INFORMAES DA CONTA A PAGAR, RETIRANDO
                                       AS INFORMAES ATUALIZADAS NA APROVAO*/
                                       UPDATE CONTAPAGAR
                                          SET
                                             CDTPCTPAGAR = NULL,
                                             CDFILIBPAG = NULL,
                                             NRLANBOLPAG = NULL,
                                             CDCLASSFINA = NULL,
                                             CDEMPRESA = NULL,
                                             CDFIMOVFLPAG = NULL,
                                             DTMOVFLUXO = NULL,
                                             IDMOVFLUXO = NULL,
                                             DSCONTAPAG = DECODE(IDDSCONTANF,'N',NULL,DSCONTAPAG),
                                             VRATUAPAG =  VRORIGPAG
                                          WHERE CDFILIAL = C_CNTPAGAR.CDFILIAL
                                            AND NRLANCTONF = C_CNTPAGAR.NRLANCTONF
                                            AND NRSEQVENPAG = C_CNTPAGAR.NRSEQVENPAG
                                            AND NRPARCELAPAG = C_CNTPAGAR.NRPARCELAPAG;

                                       SELECT COUNT(*)
                                         INTO V_COUNT
                                         FROM CONTAPAGAR
                                        WHERE CDFILIBPAG = C_CNTPAGAR.CDFILIBPAG
                                          AND NRLANBOLPAG = C_CNTPAGAR.NRLANBOLPAG;

                                       /*APAGA O BOLETO RELACIONADO  CONTA A PAGAR*/
                                       IF V_COUNT = 0 THEN
                                          DELETE FROM BOLETPAGAR
                                           WHERE CDFILIAL = C_CNTPAGAR.CDFILIBPAG
                                             AND NRLANBOLPAG = C_CNTPAGAR.NRLANBOLPAG;
                                       END IF;
                                    END LOOP;

                                    /*ATUALIZAO DAS CONTAS A PAGAR RELACIONADAS  AUTORIZAO DE FORNECIMENTO*/
                                    FOR C_NOTA IN (SELECT CDFILIALIT, NRLANCTONFIT
                                                     FROM ITEMNOTAFISC
                                                    WHERE CDFILIAL = P_CDFILIAL
                                                      AND NRLANCTONF = P_NRLANCTONF) LOOP

                                       AJUSTE_CONTAPAGAR_NF(C_NOTA.CDFILIALIT,
                                                            C_NOTA.NRLANCTONFIT,
                                                           'P');
                                    END LOOP;

                                    AJUSTE_CONTAPAGAR_NF(P_CDFILIAL,
                                                         P_NRLANCTONF,
                                                         'P');
                                 END IF;
                              END IF;
                           END IF;
                        END IF;
                     END IF;
                  END IF;
               END IF;
            END IF;
         END IF;
      END IF;
   /*NOTA FISCAL DE SADA*/
   ELSIF V_IDENTRSAID = 'S' THEN


      /*VERIFICA EXISTNCIA DE CONTA A RECEBER BAIXADA*/
      SELECT COUNT(BO.CDFILIAL)
        INTO V_COUNT
        FROM CONTARECEBER CR,
             BOLETRECEBER BO
       WHERE (CR.CDFILIAL    = P_CDFILIAL)
         AND (CR.NRLANCTONF  = P_NRLANCTONF)
         AND (BO.CDFILIAL    = CR.CDFILIBOLREC)
         AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
         AND (BO.NRBAIXAREC IS NOT NULL);
      IF V_COUNT > 0 THEN
         P_RETORNO := 1;
      ELSE
         /*VERIFICA EXISTNCIA DE CONTAS PARCELADAS*/
         SELECT COUNT(*)
           INTO V_COUNT
           FROM CONTARECEBER CR
          WHERE (CR.CDFILIAL = P_CDFILIAL)
            AND (CR.NRLANCTONF = P_NRLANCTONF)
            AND (NVL(CR.IDPARCAUTOFOS,'N') = 'N')
            AND (SELECT COUNT(*)
                   FROM CONTARECEBER
                  WHERE CDFILIAL = CR.CDFILIAL
                    AND NRLANCTONF = CR.NRLANCTONF
                    AND NRSEQVENREC = CR.NRSEQVENREC) > 1;
         IF V_COUNT > 0 THEN
            P_RETORNO := 2;
         ELSE
            /*VERIFICA EXISTNCIA DE BOLETO EMITIDO*/
            SELECT COUNT(BO.CDFILIAL)
              INTO V_COUNT
              FROM CONTARECEBER CR,
                   BOLETRECEBER BO,
                   CLIENTE      CL
             WHERE (CR.CDFILIAL = P_CDFILIAL)
               AND (CR.NRLANCTONF = P_NRLANCTONF)
               AND (BO.CDFILIAL = CR.CDFILIBOLREC)
               AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
               AND (BO.IDSTATBREC = 'E')
               AND (CL.CDCLIENTE = BO.CDCLIENTE)
               AND (NVL(CL.IDENVBOLANTNOTA,'N') <> 'S');
            IF V_COUNT > 0 THEN
               P_RETORNO := 5;
            ELSE
               /*VERIFICA EXISTNCIA DE BOLETO LIGADO  REMESSA*/
               SELECT COUNT(BO.CDFILIAL)
                 INTO V_COUNT
                 FROM CONTARECEBER CR,
                      BOLETRECEBER BO
                WHERE (CR.CDFILIAL = P_CDFILIAL)
                  AND (CR.NRLANCTONF = P_NRLANCTONF)
                  AND (BO.CDFILIAL = CR.CDFILIBOLREC)
                  AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
                  AND (IDSITUCNABR <> '00');
               IF V_COUNT > 0 THEN
                  P_RETORNO := 6;
               ELSE
                  /*VERIFICA EXISTNCIA DE BOLETO ASSOCIADO  NOTA FISCAL DIFERENTE*/
                  SELECT COUNT(BO.CDFILIAL)
                    INTO V_COUNT
                    FROM CONTARECEBER CR,
                         BOLETRECEBER BO
                   WHERE (CR.CDFILIAL = P_CDFILIAL)
                     AND (CR.NRLANCTONF = P_NRLANCTONF)
                     AND (BO.CDFILIAL = CR.CDFILIBOLREC)
                     AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
                     AND (SELECT COUNT(*)
                            FROM CONTARECEBER
                           WHERE CDFILIBOLREC = BO.CDFILIAL
                             AND NRLANBOLREC = BO.NRLANBOLREC) > 1;
                  IF V_COUNT > 0 THEN
                     P_RETORNO := 7;
                  ELSE
                     /*VERIFICA SE A NOTA FISCAL DE DEVOLUO TEM VALOR UTILIZADO*/
                     SELECT NVL(VRDEVOLNFUTL,0) VRDEVOLNFUTL
                       INTO V_COUNT
                       FROM NOTAFISCAL
                      WHERE CDFILIAL = P_CDFILIAL
                        AND NRLANCTONF = P_NRLANCTONF;
                     IF V_COUNT > 0 THEN
                        P_RETORNO := 8;
                     ELSE
                        /*PESQUISA A EXISTNCIA DE AJUSTES NOS BOLETOS DAS CONTAS*/
                        SELECT COUNT(AJ.CDFILIAL)
                          INTO V_COUNT
                          FROM CONTARECEBER CR,
                               AJBOLREC   AJ
                         WHERE (CR.CDFILIAL = P_CDFILIAL)
                           AND (CR.NRLANCTONF = P_NRLANCTONF)
                           AND (AJ.CDFILIAL = CR.CDFILIBOLREC)
                           AND (AJ.NRLANBOLREC = CR.NRLANBOLREC);
                        IF V_COUNT > 0 THEN
                           P_RETORNO := 4;
                        ELSE
                           P_RETORNO := 0;

                           IF (NVL(P_IDCANFIN, 'S') = 'S') THEN
                              /*APAGA AS CONTAS A RECEBER*/
                              FOR C_CNTRECEBER IN (SELECT CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC,
                                                          CDFILIBOLREC, NRLANBOLREC, DTATUAVENREC, VRORIGREC,
                                                          CDEMPRESA, CDFIMOVFLREC, CDCLASSFINA, DTMOVFLUXO, IDMOVFLUXO
                                                     FROM CONTARECEBER
                                                    WHERE CDFILIAL = P_CDFILIAL
                                                      AND NRLANCTONF = P_NRLANCTONF) LOOP
                                  /*ATUALIZA ORAMENTO FINANCEIRO FINANCEIRO*/
                                 ORCAMENTO_OK(C_CNTRECEBER.CDEMPRESA,
                                              C_CNTRECEBER.CDFIMOVFLREC,
                                              C_CNTRECEBER.CDCLASSFINA,
                                              C_CNTRECEBER.DTATUAVENREC,
                                              C_CNTRECEBER.VRORIGREC * -1,
                                              V_RESULTADO);
                                 /*APAGA O RATEIO DA CONTA A PAGAR*/
                                 DELETE FROM RATCTRECEBER
                                  WHERE CDFILIAL     = C_CNTRECEBER.CDFILIAL
                                    AND NRLANCTONF   = C_CNTRECEBER.NRLANCTONF
                                    AND NRSEQVENREC  = C_CNTRECEBER.NRSEQVENREC
                                    AND NRPARCELAREC = C_CNTRECEBER.NRPARCELAREC;
                                 /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                 FOR C_AJRECEBER IN (SELECT AJ.CDFILIAL, AJ.NRLANCTONF, AJ.NRSEQVENREC, AJ.NRPARCELAREC,
                                                          AJ.DTAJUSTEREC, AJ.CDAJUCTREC, T.IDAJUCTREC, AJ.CDEMMFAJCNTR,
                                                          AJ.CDFIMFAJCNTR, AJ.CDCLASSFINA, AJ.IDMOVFLUXO, AJ.VRAJUSTEREC,
                                                          AJ.DTMOVFLUXO
                                                     FROM AJCTRECEBER AJ, TIPOAJRECEBER T
                                                    WHERE AJ.CDFILIAL = C_CNTRECEBER.CDFILIAL
                                                      AND AJ.NRLANCTONF = C_CNTRECEBER.NRLANCTONF
                                                      AND AJ.NRSEQVENREC = C_CNTRECEBER.NRSEQVENREC
                                                      AND AJ.NRPARCELAREC = C_CNTRECEBER.NRPARCELAREC
                                                      AND AJ.CDAJUCTREC = T.CDAJUCTREC) LOOP
                                    IF C_AJRECEBER.IDAJUCTREC = 'D' THEN
                                       V_FATOR := 1;
                                    ELSE
                                       V_FATOR := -1;
                                    END IF;
                                    IF NOT (C_AJRECEBER.CDEMMFAJCNTR IS NULL)
                                       AND NOT (C_AJRECEBER.CDFIMFAJCNTR IS NULL)
                                       AND NOT (C_AJRECEBER.DTMOVFLUXO IS NULL)
                                       AND NOT (C_AJRECEBER.CDCLASSFINA IS NULL) THEN
                                       /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                       ATUALIZA_FLUXO_DE_CAIXA(C_AJRECEBER.CDEMMFAJCNTR,
                                                               C_AJRECEBER.CDFIMFAJCNTR,
                                                               C_AJRECEBER.DTMOVFLUXO,
                                                               C_AJRECEBER.IDMOVFLUXO,
                                                               C_AJRECEBER.CDCLASSFINA,
                                                               C_AJRECEBER.VRAJUSTEREC * V_FATOR,
                                                               0);
                                    END IF;
                                    /*APAGA OS AJUSTES DA CONTA A RECEBER*/
                                    DELETE FROM AJCTRECEBER
                                     WHERE (CDFILIAL     = C_AJRECEBER.CDFILIAL)
                                       AND (NRLANCTONF   = C_AJRECEBER.NRLANCTONF)
                                       AND (NRSEQVENREC  = C_AJRECEBER.NRSEQVENREC)
                                       AND (NRPARCELAREC = C_AJRECEBER.NRPARCELAREC)
                                       AND (DTAJUSTEREC  = C_AJRECEBER.DTAJUSTEREC)
                                       AND (CDAJUCTREC   = C_AJRECEBER.CDAJUCTREC);
                                 END LOOP;
                                 /*ATUALIZA O FLUXO DE CAIXA DA CONTA A RECEBER*/
                                 IF NOT (C_CNTRECEBER.CDEMPRESA IS NULL)
                                    AND NOT (C_CNTRECEBER.CDFIMOVFLREC IS NULL)
                                    AND NOT (C_CNTRECEBER.DTMOVFLUXO IS NULL)
                                    AND NOT (C_CNTRECEBER.CDCLASSFINA IS NULL) THEN
                                    ATUALIZA_FLUXO_DE_CAIXA(C_CNTRECEBER.CDEMPRESA,
                                                            C_CNTRECEBER.CDFIMOVFLREC,
                                                            C_CNTRECEBER.DTMOVFLUXO,
                                                            C_CNTRECEBER.IDMOVFLUXO,
                                                            C_CNTRECEBER.CDCLASSFINA,
                                                            C_CNTRECEBER.VRORIGREC * -1,
                                                            0);
                                 END IF;
                                 /*ATUALIZA AS INFORMAES DA CONTA A RECEBER, RETIRANDO
                                 AS INFORMAES ATUALIZADAS NA APROVAO*/
                                 UPDATE CONTARECEBER
                                    SET
                                       CDTPCTRECEB = NULL,
                                       CDFILIBOLREC = NULL,
                                       NRLANBOLREC = NULL,
                                       CDCLASSFINA = NULL,
                                       CDEMPRESA = NULL,
                                       CDFIMOVFLREC = NULL,
                                       DTMOVFLUXO = NULL,
                                       IDMOVFLUXO = NULL,
                                       DSCONTAREC = NULL,
                                       VRATUAREC =  VRORIGREC
                                    WHERE CDFILIAL = C_CNTRECEBER.CDFILIAL
                                      AND NRLANCTONF = C_CNTRECEBER.NRLANCTONF
                                      AND NRSEQVENREC = C_CNTRECEBER.NRSEQVENREC
                                      AND NRPARCELAREC = C_CNTRECEBER.NRPARCELAREC;
                                 /*APAGA O BOLETO RELACIONADO  CONTA A RECEBER*/
                                 DELETE FROM BOLETRECEBER
                                  WHERE CDFILIAL = C_CNTRECEBER.CDFILIBOLREC
                                    AND NRLANBOLREC = C_CNTRECEBER.NRLANBOLREC;
                              END LOOP;
                           END IF;
                        END IF;
                     END IF;
                  END IF;
               END IF;
            END IF;
         END IF;
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('CANCELA_DADOS_FINANCEIRO','6.35.021'); END;
/

